Additional services
===================

In this chapter, we introduce services crossing the *web -
repository - administration* organisation of the first parts of the
CubicWeb book. Those services can be either proper services (like the
undo functionality) or mere *topical cross-sections* across CubicWeb.

.. toctree::
   :maxdepth: 2

   undo


